"""
This modules host Elasticsearch based methods to compute various insight
"""

# flake8: noqa
from .client import get_es_client
